documentationtools.ReSTTOCItem
==============================

.. abjad-lineage:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem

.. autoclass:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.depth
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.graph_order
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.parent
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.rest_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.name
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.text
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__ge__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__getstate__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__gt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__le__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__lt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__repr__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTTOCItem.ReSTTOCItem.ReSTTOCItem.__setstate__
   :noindex:
